@@ -4,7 +4,7 @@ use warnings;
 use base qw/Exporter/;
 use File::Spec;
 
-our @EXPORT_OK = qw/add_method/;
+our @EXPORT_OK = qw/add_method random_string/;
 
 sub add_method {
     my ($klass, $method, $code) = @_;
@@ -23,4 +23,14 @@ sub base_dir($) {
     }
 }
 
+sub random_string {
+    my $length = shift;
+    my @chars = ( 'A'..'Z', 'a'..'z', '0'..'9' );
+    my $ret;
+    for (1..$length) {
+        $ret .= $chars[int rand @chars];
+    }
+    return $ret;
+}
+
 1;
